import os
import atexit
import signal
import logging
import threading
import subprocess


from pathlib import Path

logger = logging.getLogger(__name__)
logger.addHandler(logging.NullHandler())


class Player(object):
    
    def __init__(self, source,
                 args=None):
        logger.debug('Instantiating OMXPlayer')

        if args is None:
            self.args = []
        elif isinstance(args, str):
            import shlex
            self.args = shlex.split(args)
        else:
            self.args = list(map(str, args))
        self._source = Path(source)

        self._process = None
        self._force_kill()
        self.load(source)
        
    def _force_kill(self):
        try:
            subprocess.call(["killall", "omxplayer.bin"])
        finally:
            pass 

    def load(self, source):
        self._source = source
        self._process = self._setup_omxplayer_process(source)

    def _run_omxplayer(self, source, devnull):
        def on_exit(self, exit_status):
            logger.info("OMXPlayer process is dead, all DBus calls from here "
                        "will fail")
            self.exitEvent(self, exit_status)

        def monitor(self, process, on_exit):
            process.wait()
            on_exit(self, process.returncode)

        try:
            source = str(source.resolve())
        except AttributeError:
            pass
        command = ['omxplayer'] + self.args + [source]
        logger.debug("Opening omxplayer with the command: %s" % command)
        
        try:
            process = subprocess.Popen(command,
                                    stdin=devnull,
                                    stdout=devnull,
                                    preexec_fn=os.setsid)
        except:
            if os.getenv("DEBUG"):
                logger.debug("Process omxplayer faliture")
                return None
            else:
                raise
        try:
            self._process_monitor = threading.Thread(target=monitor,
                                                     args=(self, process, on_exit))
            self._process_monitor.start()
            return process
        except:
            # Make sure to not leave any dangling process on failure
            self._terminate_process(process)
            raise

    def _setup_omxplayer_process(self, source):
        logger.debug('Setting up OMXPlayer process')

        with open(os.devnull, 'w') as devnull:
            process = self._run_omxplayer(source, devnull)
        logger.debug('Process opened with PID %s' % process)

        return process

    def _terminate_process(self, process):
        try:
            process_group_id = os.getpgid(process.pid)
            os.killpg(process_group_id, signal.SIGTERM)
            logger.debug('SIGTERM Sent to pid: %s' % process_group_id)
        except OSError:
            logger.error('Could not find the process to kill')


import os


from googleapiclient import discovery
from httplib2 import Http
from oauth2client import file, client, tools


def get_cred(path):
    store_path = os.path.join(path, 'storage.json')
    store = file.Storage(store_path)
    creds = store.get()
    if not creds or creds.invalid:
        SCOPES = 'https://www.googleapis.com/auth/drive.metadata.readonly'
        args = tools.argparser.parse_args(args=["--noauth_local_webserver"])
        secret_path = os.path.join(path, 'secret.json')
        flow = client.flow_from_clientsecrets(secret_path, SCOPES)
        creds = tools.run_flow(flow, store, args)
    return creds

def list_files(path):
    creds = get_cred(path)
    DRIVE = discovery.build('drive', 'v3', http=creds.authorize(Http()))
    return DRIVE.files().list().execute().get('files', [])


import setuptools
setuptools.setup(
    name='berry_video',
    version='0.0.2',
    scripts=['script/berry'],
    author='Mr Menezes',
    author_email='sr.tama@outlook.com',
    license='@copyright',
    description='Tools of berry video',
    packages=['berry_video'],
    install_requires=[
        'setuptools',
        'google-api-python-client==2.12.0',
        'oauth2client==4.1.3',
        'python_crontab==2.5.1',
    ],
    python_requires='>=3.5'
)


import logging
import getpass


from crontab import CronTab


logger = logging.getLogger(__name__)
logger.addHandler(logging.NullHandler())


def auto_start():
    cron = CronTab(user=getpass.getuser())
    for job in cron:
        if job.comment =="start":
            logger.info("Cron de start ja criada")
            return
    
    job = cron.new(command="berry start", comment="start")
    job.every_reboot()
    job.enable()
    cron.write()
    logger.info("Cron de start criada")

def set_update(minutes):
    cron = CronTab(user=getpass.getuser())
    for job in cron:
        if job.comment =="update":
            job.minute.every(minutes)
            job.enable()
            cron.write()
            logger.info("Cron de update atualizada")
            return
    
    job = cron.new(command="berry update", comment="update")
    job.minute.every(minutes)
    job.enable()
    cron.write()
    logger.info("Cron de update criada")
